@@ -321,8 +321,11 @@ HostToMask (char *username, char *hostname)
     /* 
      * only use the last 8 characters of the username if there 
      * are more
+     *
+     * >=10, not >10. We lost one character to the * prefix
+     *  -- asuffield
      */
-    if ((host - realhost) > 10)
+    if ((host - realhost) >= 10)
       user = host - 8;
 
     /* now store the username into 'final' */
