@@ -93,6 +93,7 @@ static void CheckServCollide(struct Server *bad_server);
 
 #if defined(NICKSERVICES) && defined(CHANNELSERVICES)
 static void s_topic(int ac, char **av);
+static void s_stopic(int ac, char **av);
 #endif
 
 #ifdef STATSERVICES
@@ -113,6 +114,7 @@ static struct ServCommand servtab[] = {
   { "QUIT", s_quit },
   { "KILL", s_kill },
   { "KICK", s_kick },
+  { "REMOVE", s_kick },
   { "MODE", s_mode },
   { "SJOIN", s_sjoin },
   { "JOIN", s_sjoin },
@@ -125,6 +127,7 @@ static struct ServCommand servtab[] = {
 
 #if defined(NICKSERVICES) && defined(CHANNELSERVICES)
   { "TOPIC", s_topic },
+  { "STOPIC", s_stopic },
 #endif
 
 #ifdef STATSERVICES
@@ -2198,7 +2201,8 @@ s_version(int ac, char **av)
   if (ac < 3)
     return;
 
-  if (irccmp(Me.name, (av[2][0] == ':') ? av[2] + 1 : av[2]) != 0)
+  if ((irccmp("*", (av[2][0] == ':') ? av[2] + 1 : av[2]) != 0) &&
+      (irccmp(Me.name, (av[2][0] == ':') ? av[2] + 1 : av[2]) != 0))
     return;
 
   if (av[0][0] == ':')
@@ -2210,7 +2214,7 @@ s_version(int ac, char **av)
     "*** Remote version query requested by %s",
     who);
 
-  toserv(":%s 351 %s dancer-services-%s. %s :TS3\n",
+  toserv(":%s 351 %s dancer-services-%s. %s :dncrTS/v4\n",
     Me.name,
     who,
     hVersion,
@@ -2300,7 +2304,7 @@ av[2]
   av[0] = who
   av[1] = "TOPIC"
   av[2] = channel
-  av[3]- = new topic
+  av[3] = new topic
 */
 
 static void
@@ -2316,7 +2320,37 @@ s_topic(int ac, char **av)
     av[0] + 1,
     av[3] + 1);
 
-  cs_CheckTopic(av[0] + 1, av[2]);
+  cs_CheckTopic(av[0] + 1, av[2], av[3] + 1, current_ts);
+} /* s_topic() */
+
+/*
+s_stopic()
+  Check if topic change conflicts with a locked topic on channel
+av[2]
+
+  av[0] = who
+  av[1] = "STOPIC"
+  av[2] = channel
+  av[3] = topic nick
+  av[4] = topic ts
+  av[5] = channel ts
+  av[6] = new topic
+*/
+
+static void
+s_stopic(int ac, char **av)
+
+{
+  if (ac < 4)
+    return;
+
+  SendUmode(OPERUMODE_T,
+	    "*** %s: STopic from %s by %s (%s) at %s",
+	    av[2],
+	    av[0] + 1,
+	    av[3], av[6] + 1, av[4]);
+
+  cs_CheckTopic(av[3], av[2], av[6] + 1, strtoul(av[4], NULL, 0));
 } /* s_topic() */
 
 #endif
